@@ -1,6 +1,8 @@
 #undef PACKAGE
 #undef VERSION
 
+#undef GETTEXT_PACKAGE
+
 #undef ENABLE_NLS
 #undef HAVE_CATGETS
 #undef HAVE_GETTEXT
@@ -10,6 +12,7 @@
 #undef PACKAGE_LOCALE_DIR
 #undef PACKAGE_DATA_DIR
 #undef PACKAGE_SOURCE_DIR
+#undef LOCALEDIR
 
 #undef HAVE_LIBGTOP
 #undef LIBGTOP_MAJOR_VERSION
